@@ -1,5 +1,4 @@
-"""
-The module implements a ask to proceed function
+"""The module implements a ask to proceed function.
 
 :author: Julian M. Kleber
 """
@@ -16,9 +15,9 @@ from lia.emojis import (
 
 
 def ask_to_proceed() -> None:
-    """
-    The ask_to_proceed function asks the user if they want to proceed with the script.
-    If they answer 'y', then it will continue. If they answer 'n', then it will exit.
+    """The ask_to_proceed function asks the user if they want to proceed with
+    the script. If they answer 'y', then it will continue. If they answer 'n',
+    then it will exit.
 
     :return: None.
 
