@@ -1,5 +1,4 @@
-"""
-Module that makes Lia to help you avoiding mistakes in git operations
+"""Module that makes Lia to help you avoiding mistakes in git operations.
 
 :author: Julian M. Kleber
 """
@@ -19,13 +18,10 @@ from lia.check_git.ask_to_proceed import ask_to_proceed
 
 
 def verify_branch() -> None:
-    """
-    The verify_branch function checks the current branch
-    of the git repository. If it is master, then we
-    exit with an error message. If it is main, then we ask
-    the user if they want to proceed (and exit if not).
-    Otherwise, we assume that everything is fine and
-    continue on our merry way.
+    """The verify_branch function checks the current branch of the git
+    repository. If it is master, then we exit with an error message. If it is
+    main, then we ask the user if they want to proceed (and exit if not).
+    Otherwise, we assume that everything is fine and continue on our merry way.
 
     :return: None.
 
