@@ -1,5 +1,4 @@
-"""
-This is an emoji map for usage in shell outputs
+"""This is an emoji map for usage in shell outputs.
 
 :author: Julian M. Kleber
 """
